#!/bin/bash

# Cek path tempat script ini berada
mypath="$(cd "$(dirname "$0")" ; pwd)"

# Rsync
RSYNC=`which rsync`

get_conf() {
	key=$1
	"$mypath/korporat.sh" -c$key
}

get_app_conf() {
	key=$1
	"$mypath/korporat.sh" -a$key
}

# Prosedur upload data
syncup () {
	src=$1
	dst=$2
	excfile=$3
	if [ -z "$excfile" ]; then
		excfile="$mypath/app/res/rsync-exclude.txt"
	fi
	echo "Running rsync:"
	echo "   source=$src"
	echo "   destination=$remote_user@$remote_host::${target_module}${dst}"
	$RSYNC -avzh --no-perms --progress $src $remote_user@$remote_host::${target_module}${dst} --password-file $passfile --exclude-from="$excfile"
	# Added by rizki.rivai to include new server
	$RSYNC -rqlDzh $src datasync@rsync2.pti-cosmetics.com::${target_module}${dst} --password-file $passfile --exclude-from="$excfile"
}

# Prosedur download data
syncdown () {
	src=$1
	dst=$2
	echo "Running rsync:"
	echo "   source=$remote_user@$remote_host::${target_module}${src}"
	echo "   destination=$dst"
	$RSYNC -avzh --progress $remote_user@$remote_host::${target_module}${src} $dst --password-file $passfile
}

echo "Configuring"

echo "Syncing"
NAMA_DC=$(get_app_conf DC.NAME)
CR_ID=$(get_app_conf DC.CID)
KOR_DATABASE_DIR=$(get_conf dbPath)

echo "DB Dir : $KOR_DATABASE_DIR"
echo "DC Name: $NAMA_DC"
echo "CR ID  : $CR_ID"

# Konfigurasi remote host
remote_host="rsync.pti-cosmetics.com"
remote_user="ptiuser"
target_module="datapti"
passfile="$HOME/.korporat/sync.secret"
if [ ! -f "$passfile" ]; then
	echo "Password file does not exist."
	exit 1
fi
if [ $(stat -c '%a' "$passfile") -gt 600 ]; then
	echo "Password file permissions should be 600 or less."
	exit 2
fi

syncedDir="$KOR_DATABASE_DIR/pti/da"

# Tambahkan keterangan tanggal update
echo `date -Iseconds` > "$syncedDir"/tglupdate

# Upload data DC ke pusat
target_dir="/"$NAMA_DC"/da/"
if [ ! -z "$CR_ID" -a "$CR_ID" != "???" ]; then
	target_dir="/CR/"$CR_ID"/da/"
fi
source_dir="$syncedDir/"
if [ ! -z "$DISPLAY" ]; then
	syncup "$source_dir" "$target_dir" | awk -f "$mypath/app/res/rsync-monitor.awk" | zenity --progress --title="Korporat - Sync Data" --text="Syncing data" --percentage=0
else
	syncup "$source_dir" "$target_dir"
fi

# Download data NDC dari pusat
source_dir="/AllDC/ndc/"
mkdir -p "$KOR_DATABASE_DIR/pti/shared"
target_dir="$KOR_DATABASE_DIR/pti/shared/ndc/"
mkdir -p "$target_dir"
if [ ! -z "$DISPLAY" ]; then
	syncdown "$source_dir" "$target_dir"  | awk -f "$mypath/app/res/rsync-monitor.awk" | zenity --progress --title="Korporat - Sync Data" --text="Syncing data" --percentage=0
else
	syncdown "$source_dir" "$target_dir"
fi

# Download data global dari pusat
source_dir="/Global/"
target_dir="$KOR_DATABASE_DIR/pti/global"
mkdir -p "$target_dir"
if [ ! -z "$DISPLAY" ]; then
	syncdown "$source_dir" "$target_dir"  | awk -f "$mypath/app/res/rsync-monitor.awk" | zenity --progress --title="Korporat - Sync Data" --text="Syncing data" --percentage=0
else
	syncdown "$source_dir" "$target_dir"
fi
